@@ -15,8 +15,8 @@ class User:
     def __setup__(cls):
         super(User, cls).__setup__()
         cls._error_messages.update({
-                'set_passwd_ldap_user': \
-                    'You can not set a password to a ldap user!',
+                'set_passwd_ldap_user': ('You can not set the password of ldap '
+                    'user "%s".'),
                 })
 
     @staticmethod
@@ -61,16 +61,21 @@ class User:
                 if cls.ldap_search_user(login,
                         con, connection, attrs=[]):
                     find = True
+                    break
         except Exception:
             pass
         if find:
-            cls.raise_user_error('set_passwd_ldap_user')
+            cls.raise_user_error('set_passwd_ldap_user', (login.rec_name,))
 
     @classmethod
-    def create(cls, values):
-        if values.get('password') and 'login' in values:
-            cls._check_passwd_ldap_user([values['login']])
-        return super(User, cls).create(values)
+    def create(cls, vlist):
+        tocheck = []
+        for values in vlist:
+            if values.get('password') and 'login' in values:
+                tocheck.append(values['login'])
+        if tocheck:
+            cls._check_passwd_ldap_user(tocheck)
+        return super(User, cls).create(vlist)
 
     @classmethod
     def write(cls, users, values):
@@ -127,11 +132,11 @@ class User:
                 if user_id:
                     return user_id
                 elif connection.auth_create_user:
-                    user = cls.create({
-                            'name': attrs.get(str(connection.auth_uid),
-                                [login])[0],
-                            'login': login,
-                            })
+                    user, = cls.create([{
+                                'name': attrs.get(str(connection.auth_uid),
+                                    [login])[0],
+                                'login': login,
+                                }])
                     return user.id
         except Exception:
             pass
